@@ -97,6 +97,9 @@ Dynamic configuration parameters:
     <OUTPUT>_primary: apply the primary to the OUTPUT
         Example: DP1_primary = True
 
+Format placeholders:
+    {output} xrandr output
+
 Color options:
     color_bad: Displayed layout unavailable
     color_degraded: Using a fallback layout
@@ -390,10 +393,12 @@ class Py3status:
                     if not workspace:
                         continue
                     # switch to workspace
-                    cmd = 'i3-msg workspace "{}"'.format(workspace)
+                    cmd = '{} workspace "{}"'.format(self.py3.get_wm_msg(), workspace)
                     self.py3.command_run(cmd)
                     # move it to output
-                    cmd = 'i3-msg move workspace to output "{}"'.format(output)
+                    cmd = '{} move workspace to output "{}"'.format(
+                        self.py3.get_wm_msg(), output
+                    )
                     self.py3.command_run(cmd)
                     # log this
                     self.py3.log(
